@@ -3,12 +3,12 @@
 # License: MIT
 
 import logging
-from shutil import which
 import os
-import subprocess
 import shlex
-from typing import List, Tuple
+import subprocess
 from platform import system
+from shutil import which
+from typing import List, Tuple
 
 IS_WIN = system() in ["Windows", "cli"]
 NUL = "NUL" if IS_WIN else "/dev/null"
@@ -83,7 +83,9 @@ def quoted_cmd(cmd: List[str]) -> str:
     return " ".join([shlex.quote(c) for c in cmd])
 
 
-def run_command(cmd, dry_run: bool = False, allow_error: bool = False) -> Tuple[str, str]:
+def run_command(
+    cmd, dry_run: bool = False, allow_error: bool = False
+) -> Tuple[str, str]:
     """
     Run a command directly
     """
